@@ -1,6 +1,5 @@
 from repod.common.enums import (
     ArchitectureEnum,
-    pkg_types_for_pkgtype_regex,
     tar_compression_types_for_filename_regex,
 )
 
@@ -20,7 +19,6 @@ OPTIONS = r"(!|)[\w\-.]+"
 PKGREL = r"[1-9]+[0-9]*(|[.]{1}[1-9]+[0-9]*)"
 PACKAGE_NAME = r"[a-z\d_@+]+[a-z\d\-._@+]*"
 PACKAGER_NAME = r"[\w\s\-().]+"
-PKGTYPE = rf"{pkg_types_for_pkgtype_regex()}"
 RELATIVE_PATH = r"[^/][\w\d\s.,:;/_=#()@\\&$?!+%~{}<>*\-\"\'\[\]\`^]+"
 ABSOLUTE_PATH = rf"/{RELATIVE_PATH}"
 SHA256 = r"^[a-f0-9]{64}$"
